==> de.flapdoodle.embed.mongo-4.12.1-sources.jar: de/flapdoodle/embed/mongo/transitions/ImmutableExecutedMongoRestoreProcess.java <==
package de.flapdoodle.embed.mongo.transitions;

import de.flapdoodle.embed.process.types.ExecutedProcess;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * Immutable implementation of {@link ExecutedMongoRestoreProcess}.
 * <p>
 * Use the builder to create immutable instances:
 * {@code ImmutableExecutedMongoRestoreProcess.builder()}.
 */
@SuppressWarnings({"all"})
public final class ImmutableExecutedMongoRestoreProcess
    extends ExecutedMongoRestoreProcess {
  private final int returnCode;

  private ImmutableExecutedMongoRestoreProcess(int returnCode) {
    this.returnCode = returnCode;
  }

  /**
   * @return The value of the {@code returnCode} attribute
   */
  @Override
  public int returnCode() {
    return returnCode;
  }

  /**
   * Copy the current immutable object by setting a value for the {@link ExecutedMongoRestoreProcess#returnCode() returnCode} attribute.
   * A value equality check is used to prevent copying of the same value by returning {@code this}.
   * @param value A new value for returnCode
   * @return A modified copy of the {@code this} object
   */
  public final ImmutableExecutedMongoRestoreProcess withReturnCode(int value) {
    if (this.returnCode == value) return this;
    return new ImmutableExecutedMongoRestoreProcess(value);
  }

  /**
   * This instance is equal to all instances of {@code ImmutableExecutedMongoRestoreProcess} that have equal attribute values.
   * @return {@code true} if {@code this} is equal to {@code another} instance
   */
  @Override
  public boolean equals(Object another) {
    if (this == another) return true;
    return another instanceof ImmutableExecutedMongoRestoreProcess
        && equalTo(0, (ImmutableExecutedMongoRestoreProcess) another);
  }

  private boolean equalTo(int synthetic, ImmutableExecutedMongoRestoreProcess another) {
    return returnCode == another.returnCode;
  }

  /**
   * Computes a hash code from attributes: {@code returnCode}.
   * @return hashCode value
   */
  @Override
  public int hashCode() {
    int h = 5381;
    h += (h << 5) + returnCode;
    return h;
  }

  /**
   * Prints the immutable value {@code ExecutedMongoRestoreProcess} with attribute values.
   * @return A string representation of the value
   */
  @Override
  public String toString() {
    return "ExecutedMongoRestoreProcess{"
        + "returnCode=" + returnCode
        + "}";
  }

  /**
   * Creates an immutable copy of a {@link ExecutedMongoRestoreProcess} value.
   * Uses accessors to get values to initialize the new immutable instance.
   * If an instance is already immutable, it is returned as is.
   * @param instance The instance to copy
   * @return A copied immutable ExecutedMongoRestoreProcess instance
   */
  public static ImmutableExecutedMongoRestoreProcess copyOf(ExecutedMongoRestoreProcess instance) {
    if (instance instanceof ImmutableExecutedMongoRestoreProcess) {
      return (ImmutableExecutedMongoRestoreProcess) instance;
    }
    return ImmutableExecutedMongoRestoreProcess.builder()
        .from(instance)
        .build();
  }

  /**
   * Creates a builder for {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
   * <pre>
   * ImmutableExecutedMongoRestoreProcess.builder()
   *    .returnCode(int) // required {@link ExecutedMongoRestoreProcess#returnCode() returnCode}
   *    .build();
   * </pre>
   * @return A new ImmutableExecutedMongoRestoreProcess builder
   */
  public static ImmutableExecutedMongoRestoreProcess.Builder builder() {
    return new ImmutableExecutedMongoRestoreProcess.Builder();
  }

  /**
   * Builds instances of type {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
   * Initialize attributes and then invoke the {@link #build()} method to create an
   * immutable instance.
   * <p><em>{@code Builder} is not thread-safe and generally should not be stored in a field or collection,
   * but instead used immediately to create instances.</em>
   */
  public static final class Builder {
    private static final long INIT_BIT_RETURN_CODE = 0x1L;
    private long initBits = 0x1L;

    private int returnCode;

    private Builder() {
    }

    /**
     * Fill a builder with attribute values from the provided {@code de.flapdoodle.embed.process.types.ExecutedProcess} instance.
     * @param instance The instance from which to copy values
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder from(ExecutedProcess instance) {
      Objects.requireNonNull(instance, "instance");
      from((short) 0, (Object) instance);
      return this;
    }

    /**
     * Fill a builder with attribute values from the provided {@code de.flapdoodle.embed.mongo.transitions.ExecutedMongoRestoreProcess} instance.
     * @param instance The instance from which to copy values
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder from(ExecutedMongoRestoreProcess instance) {
      Objects.requireNonNull(instance, "instance");
      from((short) 0, (Object) instance);
      return this;
    }

    private void from(short _unused, Object object) {
      if (object instanceof ExecutedProcess) {
        ExecutedProcess instance = (ExecutedProcess) object;
        returnCode(instance.returnCode());
      }
    }

    /**
     * Initializes the value for the {@link ExecutedMongoRestoreProcess#returnCode() returnCode} attribute.
     * @param returnCode The value for returnCode 
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder returnCode(int returnCode) {
      this.returnCode = returnCode;
      initBits &= ~INIT_BIT_RETURN_CODE;
      return this;
    }

    /**
     * Builds a new {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
     * @return An immutable instance of ExecutedMongoRestoreProcess
     * @throws java.lang.IllegalStateException if any required attributes are missing
     */
    public ImmutableExecutedMongoRestoreProcess build() {
      if (initBits != 0) {
        throw new IllegalStateException(formatRequiredAttributesMessage());
      }
      return new ImmutableExecutedMongoRestoreProcess(returnCode);
    }

    private String formatRequiredAttributesMessage() {
      List<String> attributes = new ArrayList<>();
      if ((initBits & INIT_BIT_RETURN_CODE) != 0) attributes.add("returnCode");
      return "Cannot build ExecutedMongoRestoreProcess, some of required attributes are not set " + attributes;
    }
  }
}

==> de.flapdoodle.embed.mongo-4.20.0-sources.jar: de/flapdoodle/embed/mongo/transitions/ImmutableExecutedMongoRestoreProcess.java <==
package de.flapdoodle.embed.mongo.transitions;

import de.flapdoodle.embed.process.types.ExecutedProcess;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * Immutable implementation of {@link ExecutedMongoRestoreProcess}.
 * <p>
 * Use the builder to create immutable instances:
 * {@code ImmutableExecutedMongoRestoreProcess.builder()}.
 */
@SuppressWarnings({"all"})
public final class ImmutableExecutedMongoRestoreProcess
    extends ExecutedMongoRestoreProcess {
  private final int returnCode;

  private ImmutableExecutedMongoRestoreProcess(int returnCode) {
    this.returnCode = returnCode;
  }

  /**
   * @return The value of the {@code returnCode} attribute
   */
  @Override
  public int returnCode() {
    return returnCode;
  }

  /**
   * Copy the current immutable object by setting a value for the {@link ExecutedMongoRestoreProcess#returnCode() returnCode} attribute.
   * A value equality check is used to prevent copying of the same value by returning {@code this}.
   * @param value A new value for returnCode
   * @return A modified copy of the {@code this} object
   */
  public final ImmutableExecutedMongoRestoreProcess withReturnCode(int value) {
    if (this.returnCode == value) return this;
    return new ImmutableExecutedMongoRestoreProcess(value);
  }

  /**
   * This instance is equal to all instances of {@code ImmutableExecutedMongoRestoreProcess} that have equal attribute values.
   * @return {@code true} if {@code this} is equal to {@code another} instance
   */
  @Override
  public boolean equals(Object another) {
    if (this == another) return true;
    return another instanceof ImmutableExecutedMongoRestoreProcess
        && equalTo(0, (ImmutableExecutedMongoRestoreProcess) another);
  }

  private boolean equalTo(int synthetic, ImmutableExecutedMongoRestoreProcess another) {
    return returnCode == another.returnCode;
  }

  /**
   * Computes a hash code from attributes: {@code returnCode}.
   * @return hashCode value
   */
  @Override
  public int hashCode() {
    int h = 5381;
    h += (h << 5) + returnCode;
    return h;
  }

  /**
   * Prints the immutable value {@code ExecutedMongoRestoreProcess} with attribute values.
   * @return A string representation of the value
   */
  @Override
  public String toString() {
    return "ExecutedMongoRestoreProcess{"
        + "returnCode=" + returnCode
        + "}";
  }

  /**
   * Creates an immutable copy of a {@link ExecutedMongoRestoreProcess} value.
   * Uses accessors to get values to initialize the new immutable instance.
   * If an instance is already immutable, it is returned as is.
   * @param instance The instance to copy
   * @return A copied immutable ExecutedMongoRestoreProcess instance
   */
  public static ImmutableExecutedMongoRestoreProcess copyOf(ExecutedMongoRestoreProcess instance) {
    if (instance instanceof ImmutableExecutedMongoRestoreProcess) {
      return (ImmutableExecutedMongoRestoreProcess) instance;
    }
    return ImmutableExecutedMongoRestoreProcess.builder()
        .from(instance)
        .build();
  }

  /**
   * Creates a builder for {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
   * <pre>
   * ImmutableExecutedMongoRestoreProcess.builder()
   *    .returnCode(int) // required {@link ExecutedMongoRestoreProcess#returnCode() returnCode}
   *    .build();
   * </pre>
   * @return A new ImmutableExecutedMongoRestoreProcess builder
   */
  public static ImmutableExecutedMongoRestoreProcess.Builder builder() {
    return new ImmutableExecutedMongoRestoreProcess.Builder();
  }

  /**
   * Builds instances of type {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
   * Initialize attributes and then invoke the {@link #build()} method to create an
   * immutable instance.
   * <p><em>{@code Builder} is not thread-safe and generally should not be stored in a field or collection,
   * but instead used immediately to create instances.</em>
   */
  public static final class Builder {
    private static final long INIT_BIT_RETURN_CODE = 0x1L;
    private long initBits = 0x1L;

    private int returnCode;

    private Builder() {
    }

    /**
     * Fill a builder with attribute values from the provided {@code de.flapdoodle.embed.process.types.ExecutedProcess} instance.
     * @param instance The instance from which to copy values
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder from(ExecutedProcess instance) {
      Objects.requireNonNull(instance, "instance");
      from((short) 0, (Object) instance);
      return this;
    }

    /**
     * Fill a builder with attribute values from the provided {@code de.flapdoodle.embed.mongo.transitions.ExecutedMongoRestoreProcess} instance.
     * @param instance The instance from which to copy values
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder from(ExecutedMongoRestoreProcess instance) {
      Objects.requireNonNull(instance, "instance");
      from((short) 0, (Object) instance);
      return this;
    }

    private void from(short _unused, Object object) {
      if (object instanceof ExecutedProcess) {
        ExecutedProcess instance = (ExecutedProcess) object;
        this.returnCode(instance.returnCode());
      }
    }

    /**
     * Initializes the value for the {@link ExecutedMongoRestoreProcess#returnCode() returnCode} attribute.
     * @param returnCode The value for returnCode 
     * @return {@code this} builder for use in a chained invocation
     */
    public final Builder returnCode(int returnCode) {
      this.returnCode = returnCode;
      initBits &= ~INIT_BIT_RETURN_CODE;
      return this;
    }

    /**
     * Builds a new {@link ImmutableExecutedMongoRestoreProcess ImmutableExecutedMongoRestoreProcess}.
     * @return An immutable instance of ExecutedMongoRestoreProcess
     * @throws java.lang.IllegalStateException if any required attributes are missing
     */
    public ImmutableExecutedMongoRestoreProcess build() {
      if (initBits != 0) {
        throw new IllegalStateException(formatRequiredAttributesMessage());
      }
      return new ImmutableExecutedMongoRestoreProcess(returnCode);
    }

    private String formatRequiredAttributesMessage() {
      List<String> attributes = new ArrayList<>();
      if ((initBits & INIT_BIT_RETURN_CODE) != 0) attributes.add("returnCode");
      return "Cannot build ExecutedMongoRestoreProcess, some of required attributes are not set " + attributes;
    }
  }
}
